# Json Find And Lint
Yet Another Json Linter!
A linter to both find and lint all json files. Prints out invalid json files.

Exits non-0 when unlinted files exist, so you should be able to drop it into your CI/CD
and fail fast and hard.

Example usage:


```
    python3 -m json_fnl -ignore venv .
```

## Coming Soon!
Tests I guess.
